import java.awt.Graphics;
import java.awt.Container;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Color;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.image.BufferedImage;
import javax.swing.*;

public class Circuit extends JPanel {

    /**
     * 
     */
    private static final long serialVersionUID = 1L;
    private static final int WIDTH = 600;
    private static final int HEIGHT = 200;
    static final int FINISH_LINE = WIDTH - 50;
  
    private Chicken[] chickens;
    private BufferedImage image;
  
    Graphics g;

    Circuit() {
	image = new BufferedImage(WIDTH, HEIGHT, BufferedImage.TYPE_INT_RGB);
	g = image.getGraphics();
	setPreferredSize(new Dimension(WIDTH, HEIGHT));
	drawCircuit();
    }

    /**
     * Dessine un nouveau circuit.
     * 
     */
    public void drawCircuit() {
	g.setColor(Color.lightGray);
	g.fillRect(0, 0, WIDTH, HEIGHT);
	g.setColor(Color.red);
	g.drawLine(FINISH_LINE, 15, FINISH_LINE, HEIGHT);
	g.drawString("Finish", FINISH_LINE - 15, 10);
	repaint();
    }
  
    /**
     * Le poulet <code>winner</code> a gagne la course. La course est
     * terminee.
     * 
     * @param winner
     *            an <code>int</code> value
     */
    public void winRace(int winner) {
	for (int i = 0; i < chickens.length; i++) {
	    chickens[i].winner = winner;
	}
	System.out.println("Vainqueur : poulet numero " + winner);
    }

    public void startRace() {
	drawCircuit();
	chickens = new Chicken[2];
	chickens[0] = new Chicken(this, 0, Color.BLUE);
	chickens[1] = new Chicken(this, 1, Color.YELLOW);

	try {
	    for (;;) {
		if (Math.random() < 0.5) {
		    chickens[0].move(); // Chicken 1 moves a random distance.
		} else {
		    chickens[1].move(); // Chicken 2 moves a random distance.
		}
	    }
	} catch (EndOfRunException ex) {
	    // NO PROBLEM !
	    System.out.println(ex.getMessage());
	} catch (Exception ex) {
	    ex.printStackTrace();
	}
    }

    /**
     * Methode swing.
     * 
     * @param g
     *            a <code>Graphics</code> value
     */
    public void paintComponent(Graphics g) {
	g.drawImage(image, 0, 0, this);
    }

    /**
     * Methode swing.
     * 
     * @return an <code>int</code> value
     */
    public int getWidth() {
	return image.getWidth();
    }

    /**
     * Methode swing.
     * 
     * @return an <code>int</code> value
     */
    public int getHeight() {
	return image.getHeight();
    }

    public static void main(String args[]) throws Exception {

	JFrame window = new JFrame("* Chicken Run *");
	final Circuit c = new Circuit();
		
	JButton quitb = new JButton("QUIT");
	quitb.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    System.exit(0);
		}
	    });

	JButton startb = new JButton("START");
	startb.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
			c.startRace();
		}
	    });

	Container contentPane = window.getContentPane();
	contentPane.setLayout(new BorderLayout());
	contentPane.add(c, BorderLayout.CENTER);
	contentPane.add(quitb, BorderLayout.NORTH);
	contentPane.add(startb, BorderLayout.SOUTH);
	window.pack();
	window.setVisible(true);// window.show();
    }

}
